@@ -7,6 +7,8 @@ import yaml
 from botocore.session import Session as BotocoreSession
 
 import lobotomy
+from lobotomy import _mutator
+from lobotomy import _services
 
 
 class ReadOnlyCredentials(typing.NamedTuple):
@@ -68,7 +70,7 @@ class Session:
         profile_name: str = None,
         source_lobotomy: "Lobotomy" = None,
     ):
-        self.lobotomy: Lobotomy = source_lobotomy
+        self.lobotomy: Lobotomy = source_lobotomy or Lobotomy()
 
         self._constructed = {
             "aws_access_key_id": aws_access_key_id,
@@ -78,12 +80,12 @@ class Session:
             "botocore_session": botocore_session,
             "profile_name": profile_name,
         }
-        self._definition = source_lobotomy.get_session_data()
+        self._definition = self.lobotomy.get_session_data()
         self._data = {
             **self._definition,
             **{k: v for k, v in self._constructed.items() if v is not None},
         }
-        self._clients = {}
+        self._clients: typing.Dict[str, "lobotomy.Client"] = {}
 
     @property
     def profile_name(self) -> typing.Optional[str]:
@@ -110,6 +112,10 @@ class Session:
         service-client is a singleton such that subsequent calls for the
         same service name will return the same object.
         """
+        override = self.lobotomy.get_client_override(service_name)
+        if override is not None:
+            return override
+
         if service_name not in self._clients:
             self._clients[service_name] = lobotomy.Client(
                 self,
@@ -126,8 +132,72 @@ class Lobotomy:
     objects during lobotomy tests.
     """
 
-    def __init__(self, data: typing.Dict[str, typing.Any] = None):
+    def __init__(
+        self,
+        data: typing.Dict[str, typing.Any] = None,
+        client_overrides: typing.Dict[str, typing.Any] = None,
+    ):
         self.data = data or {}
+        self._client_overrides = client_overrides or {}
+
+    def add_client_override(self, service_name: str, client: typing.Any) -> "Lobotomy":
+        """
+        Add an override client that will be returned instead of a lobotomy client
+        within the scope of this Lobotomy's lifecycle.
+
+        :param service_name:
+            Name of the AWS boto service of the client to be overridden.
+        :param client:
+            The replacement client object that will be returned instead of a lobotomy
+            client.
+        """
+        self._client_overrides[service_name] = client
+        return self
+
+    def remove_client_override(self, service_name: str) -> "Lobotomy":
+        """
+        Removes an overridden client if such an override exists. Will do nothing if
+        the override does not currently exist.
+
+        :param service_name:
+            Name of the AWS boto service of the client to be removed as an override.
+        """
+        if service_name in self._client_overrides:
+            del self._client_overrides[service_name]
+        return self
+
+    def get_client_override(self, service_name: str) -> typing.Any:
+        """
+        Retrieves an override client if it exists.
+
+        :param service_name:
+            Name of the AWS boto service for which to fetch an override client.
+        """
+        return self._client_overrides.get(service_name)
+
+    def add_call(
+        self,
+        service_name: str,
+        method_name: str,
+        response: typing.Any = None,
+    ) -> "Lobotomy":
+        """
+        Adds a method call response to the stored data. Operates in the same fashion
+        as the CLI, in that additional adds will convert a single call into a list of
+        calls.
+
+        :param service_name:
+            Name of the AWS boto3 service in which the method call being added resides.
+        :param method_name:
+            Name of the AWS boto3 method to be called for this response within the
+            specified service.
+        :param response:
+            Boto3 response object for the given method call within the service.
+        """
+        service = _services.load_definition(service_name)
+        method = service.lookup(method_name)
+        _mutator.add_service_response(self.data, method, response)
+        return self
 
     def __call__(
         self,
@@ -167,17 +237,36 @@ class Lobotomy:
         cls,
         path: typing.Union[str, pathlib.Path],
         prefix: typing.Union[str, typing.Iterable[str]] = None,
+        client_overrides: typing.Dict[str, typing.Any] = None,
     ) -> "Lobotomy":
-        contents = pathlib.Path(path).absolute().read_text()
+        """
+        Create a patch instance.
 
-        if path.name.endswith((".yaml", ".yml")):
+        :param path:
+            Path to a configuration file containing the lobotomy data to use
+            in mock calls during the lifetime of this patch. This can be the
+            default value if a data value is set instead.
+        :param prefix:
+            An optional key or multi-key prefix within the path-loaded data
+            object where the lobotomy data resides. Use this when the
+            configuration file for the test has a broader scope.
+        :param client_overrides:
+            Optional dictionary containing mappings of service names to clients
+            that should be used in place of lobotomy clients during the lifecycle
+            of this lobotomy patch. Useful for mixing lobotomy clients with other
+            mocking clients in complex testing scenarios.
+        """
+        p = pathlib.Path(path)
+        contents = p.absolute().read_text()
+
+        if p.name.endswith((".yaml", ".yml")):
             data = yaml.safe_load(contents)
-        elif path.name.endswith(".toml"):
+        elif p.name.endswith(".toml"):
             data = toml.loads(contents)
         else:
             data = json.loads(contents)
 
-        return cls(data=_get_within(data, prefix))
+        return cls(data=_get_within(data, prefix), client_overrides=client_overrides)
 
 
 def _get_within(
